summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAnton Korobeynikov <asl@math.spbu.ru>2008-09-09 20:05:04 +0000
committerAnton Korobeynikov <asl@math.spbu.ru>2008-09-09 20:05:04 +0000
commit19e861a4ffb896f16a691d5ac869e894df3cd464 (patch)
tree70e54c4bb030e963a4d15d45abb8bb48f8447e3f /include
parent7ca9d81bce9b3ea6ed2f5e7476a6c4d15c882b2a (diff)
downloadllvm-19e861a4ffb896f16a691d5ac869e894df3cd464.tar.gz
llvm-19e861a4ffb896f16a691d5ac869e894df3cd464.tar.bz2
llvm-19e861a4ffb896f16a691d5ac869e894df3cd464.tar.xz
Make safer variant of alias resolution routine to be default
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@56005 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/GlobalAlias.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/GlobalAlias.h b/include/llvm/GlobalAlias.h
index 1081fc675f..d689ad7565 100644
--- a/include/llvm/GlobalAlias.h
+++ b/include/llvm/GlobalAlias.h
@@ -76,10 +76,10 @@ public:
/// resolveAliasedGlobal() - This method tries to ultimately resolve the alias
/// by going through the aliasing chain and trying to find the very last
/// global. Returns NULL if a cycle was found. If traverseWeak is true, then
/// the whole chain aliasing chain is traversed, otherwise - only strong
/// aliases.
- const GlobalValue* resolveAliasedGlobal(bool traverseWeak = true) const;
+ const GlobalValue* resolveAliasedGlobal(bool stopOnWeak = true) const;
// Methods for support type inquiry through isa, cast, and dyn_cast:
static inline bool classof(const GlobalAlias *) { return true; }
@@ -76,10 +76,10 @@ public:
/// resolveAliasedGlobal() - This method tries to ultimately resolve the alias
/// by going through the aliasing chain and trying to find the very last
- /// global. Returns NULL if a cycle was found. If traverseWeak is true, then
+ /// global. Returns NULL if a cycle was found. If stopOnWeak is false, then
/// the whole chain aliasing chain is traversed, otherwise - only strong
/// aliases.